@@ -49,6 +49,29 @@ class CfsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateAccessCert(self, request):
+        """创建用于访问文件系统的凭证
+
+        :param request: Request instance for CreateAccessCert.
+        :type request: :class:`tencentcloud.cfs.v20190719.models.CreateAccessCertRequest`
+        :rtype: :class:`tencentcloud.cfs.v20190719.models.CreateAccessCertResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateAccessCert", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateAccessCertResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateAutoSnapshotPolicy(self, request):
         """创建定期快照策略
 
@@ -329,6 +352,7 @@ class CfsClient(AbstractClient):
 
     def DeleteMountTarget(self, request):
         """本接口（DeleteMountTarget）用于删除挂载点
+        说明：2022年6月1日之后创建的CFS文件系统删除时无需单独调用删除挂载点操作，此API仅适用老版本的CFS实例。
 
         :param request: Request instance for DeleteMountTarget.
         :type request: :class:`tencentcloud.cfs.v20190719.models.DeleteMountTargetRequest`
@@ -351,7 +375,7 @@ class CfsClient(AbstractClient):
 
 
     def DeleteUserQuota(self, request):
-        """指定条件删除文件系统配额
+        """指定条件删除文件系统配额（仅部分Turbo实例能使用，若需要调用请提交工单与我们联系）
 
         :param request: Request instance for DeleteUserQuota.
         :type request: :class:`tencentcloud.cfs.v20190719.models.DeleteUserQuotaRequest`
@@ -744,7 +768,7 @@ class CfsClient(AbstractClient):
 
 
     def SetUserQuota(self, request):
-        """设置文件系统配额，提供UID/GID的配额设置的接口
+        """设置文件系统配额，提供UID/GID的配额设置的接口（仅部分Turbo实例能使用，若需要调用请提交工单与我们联系）
 
         :param request: Request instance for SetUserQuota.
         :type request: :class:`tencentcloud.cfs.v20190719.models.SetUserQuotaRequest`
@@ -990,6 +1014,30 @@ class CfsClient(AbstractClient):
             model = models.UpdateCfsSnapshotAttributeResponse()
             model._deserialize(response["Response"])
             return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def UpdateFileSystemBandwidthLimit(self, request):
+        """更新文件系统吞吐
+        仅吞吐型支持此接口
+
+        :param request: Request instance for UpdateFileSystemBandwidthLimit.
+        :type request: :class:`tencentcloud.cfs.v20190719.models.UpdateFileSystemBandwidthLimitRequest`
+        :rtype: :class:`tencentcloud.cfs.v20190719.models.UpdateFileSystemBandwidthLimitResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("UpdateFileSystemBandwidthLimit", params, headers=headers)
+            response = json.loads(body)
+            model = models.UpdateFileSystemBandwidthLimitResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
